class SettingsController < ApplicationController
  before_action :authenticate_user!
  before_action :set_main_nav_section
  before_action :set_settings_section, only: [:show, :update, :update_email]
  before_action :set_user, only: [:show, :update, :update_email]

  def index
    redirect_to setting_path(:profile)
  end

  def show
  end

  def update
    @user.preferences.merge!(user_params[:preferences] || {})
    @user.display_name = user_params[:display_name]

    if @user.save
      if @user.display_name && (@user.display_name != @user.ldap_entry[:display_name])
        LdapManager::UpdateDisplayName.call(@user.dn, user_params[:display_name])
      end

      redirect_to setting_path(@settings_section), flash: {
        success: 'Settings saved.'
      }
    else
      @validation_errors = @user.errors
      render :show, status: :unprocessable_entity
    end
  end

  def update_email
    if @user.valid_ldap_authentication?(email_params[:current_password])
      if @user.update email: email_params[:email]
        redirect_to setting_path(:account), flash: {
          notice: 'Please confirm your new address using the confirmation link we just sent you.'
        }
      else
        @validation_errors = @user.errors
        render :show, status: :unprocessable_entity
      end
    else
      redirect_to setting_path(:account), flash: {
        error: 'Password did not match your current password. Try again.'
      }
    end
  end

  def reset_password
    current_user.send_reset_password_instructions
    sign_out current_user
    msg = "We have sent you an email with a link to reset your password."
    redirect_to check_your_email_path, notice: msg
  end

  private

    def set_main_nav_section
      @current_section = :settings
    end

    def set_settings_section
      @settings_section = params[:section]
      allowed_sections = [:profile, :account, :lightning, :xmpp]

      unless allowed_sections.include?(@settings_section.to_sym)
        redirect_to setting_path(:profile)
      end
    end

    def set_user
      @user = current_user
    end

    def user_params
      params.require(:user).permit(:display_name, preferences: [
        :lightning_notify_sats_received,
        :xmpp_exchange_contacts_with_invitees
      ])
    end

    def email_params
      params.require(:user).permit(:email, :current_password)
    end
end
